==> haskell-dependent-sum-0.7.2.0-70-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-3OB5NRwGyYcCMwlBoEa7Kw
key:                  dependent-sum-0.7.2.0-3OB5NRwGyYcCMwlBoEa7Kw
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  f8b6978d530db74a936981d3d020b1cd
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.5-L5glA67mR8RJufLDsA2lRz:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.5-L5glA67mR8RJufLDsA2lRz:Data.GADT.Show,
    Data.Some from some-1.0.5-L5glA67mR8RJufLDsA2lRz:Data.Some

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-3OB5NRwGyYcCMwlBoEa7Kw
depends:
    base-4.16.4.0 constraints-extras-0.4.0.0-3p37kLSfD3JF2Q2cvAVNVv
    some-1.0.5-L5glA67mR8RJufLDsA2lRz

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-0.7.2.0-80-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-4h4ovsdit139tuGeWWRjdC
key:                  dependent-sum-0.7.2.0-4h4ovsdit139tuGeWWRjdC
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  7159e32badf5b850a50fbc2a772419db
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.5-L5glA67mR8RJufLDsA2lRz:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.5-L5glA67mR8RJufLDsA2lRz:Data.GADT.Show,
    Data.Some from some-1.0.5-L5glA67mR8RJufLDsA2lRz:Data.Some

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-4h4ovsdit139tuGeWWRjdC
depends:
    base-4.16.4.0 constraints-extras-0.4.0.1-1ohSO2MUFiNA1kfAGswIng
    some-1.0.5-L5glA67mR8RJufLDsA2lRz

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
